# PaymentOptionContext

Additional context specific to the payment option. This is currently only returned for Apple Pay.

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**merchant_name** | **str** | Display name of the merchant for Apple Pay. | [optional] 
**supported_schemes** | **[str]** | Supported schemes for Apple Pay. | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


